
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.18.7',
    'branch_nick': 'patch-0-Rucio_1_18_7_preparation',
    'revision_id': '9ffbf2f72d6610ff7c2dea57bef9444fc256f4ae',
    'revno': 7366
}
